translations = {
    "ru": {
        "read_more": "Далее",
        "no_posts_found": "Ничего не найдено.",
        "pagination_first_page": "к новым",
        "pagination_last_page": "к старым",
        "tags_filter_header": "Нашли постов:",
        "article_similar_header": "Похожее",
        "last_posts_header": "Последние посты",
        "similarity_score_tooltip": "Уровень похожести",
        "license": "лицензия",
        "content_repository": "исходники постов",
        "site_is_created_with": "сайт создан с помощью",
        "icons_attribution": 'сайт использует <a href="https://github.com/tabler/tabler-icons" target="_blank">Tabler Icons</a>, лицензированные под <a href="https://github.com/tabler/tabler-icons/blob/main/LICENSE" target="_blank">лицензией MIT</a>',  # noqa
    },
    "en": {
        "read_more": "Read more",
        "no_posts_found": "Nothing found.",
        "pagination_first_page": "to new",
        "pagination_last_page": "to old",
        "tags_filter_header": "Found posts:",
        "article_similar_header": "Similar",
        "last_posts_header": "Last posts",
        "similarity_score_tooltip": "Similarity score",
        "license": "license",
        "content_repository": "content repository",
        "site_is_created_with": "site is created with",
        "icons_attribution": 'site is using <a href="https://github.com/tabler/tabler-icons" target="_blank">Tabler Icons</a>, licensed under the <a href="https://github.com/tabler/tabler-icons/blob/main/LICENSE" target="_blank">MIT License</a>',  # noqa
    },
}
